@@ -1,10 +1,12 @@
-from abc import ABC, abstractmethod
-from collections import namedtuple
 import csv
 import tempfile
+from abc import ABC, abstractmethod
+from collections import namedtuple
+
 import ndjson
-from . import logger, tinybird
-from .export import Data, URL, LocalFile, CloudFile, CloudDir
+
+from . import errors, logger, tinybird
+from .export import URL, CloudDir, CloudFile, Data, LocalFile
 
 Scope = namedtuple('Scope', 'name value')
 
@@ -24,6 +26,9 @@ class Connector:
     def __exit__(self, exc_type, exc_val, _exc_tb):
         if exc_type:
             logger.error(f'Exception raised: {exc_val!r}')
+            if not issubclass(exc_type, errors.Error):
+                # exc_val.message may not exist, just call str().
+                raise errors.Error(str(exc_val)) from exc_val
         return False
 
     def query_tb(self, sql, pipe=None, scalar=False):
@@ -102,9 +107,8 @@ class SQLConnector(Connector, ABC):
                 if cat_key := export.client.cat(export.bucket, export.directory):
                     url = export.client.public_url(export.bucket, cat_key)
                     return self.tb.append_url(url, data_source, fmt)
-                else:
-                    logger.info('No files found in directory, skipping append')
-                    return
+                logger.info('No files found in directory, skipping append')
+                return None
             raise Exception(f'Unknown export type {export!r}')
         finally:
             export.cleanup()
@@ -130,9 +134,8 @@ class SQLConnector(Connector, ABC):
                 if cat_key := export.client.cat(export.bucket, export.directory):
                     url = export.client.public_url(export.bucket, cat_key)
                     return self.tb.replace_url(url, data_source, fmt, replace_condition)
-                else:
-                    logger.info('No files found in directory, skipping replace')
-                    return
+                logger.info('No files found in directory, skipping replace')
+                return None
             raise Exception(f'Unknown export type {export!r}')
         finally:
             export.cleanup()
