@@ -1,6 +1,11 @@
 import mysql.connector
-from tinybird_cdk import config, connector, export, formats, errors
 
+from tinybird_cdk import config, connector, errors, export, formats
+
+
+# WARNING: THIS CONNECTOR WAS JUST PROTOTYPED TO HELP DESIGN THE CDK, BUT IT IS
+# NOT USED AND IT DOES NOT HAVE TESTS.
+#
 # The environment variables supported by this connector are documented here:
 #
 #     https://dev.mysql.com/doc/refman/8.0/en/environment-variables.html
@@ -11,13 +16,13 @@ class Connector(connector.SQLConnector):
         self.database = config.get('MYSQL_DATABASE')
 
     def get_scopes(self):
-        raise 'Not implemented'
+        raise Exception('Not implemented')
 
     def list_scope(self, _parents={}):
-        raise 'Not implemented'
+        raise Exception('Not implemented')
 
-    def suggest_schema(self, parents):
-        raise 'Not implemented'
+    def suggest_schema(self, _scopes):
+        raise Exception('Not implemented')
 
     def _query(self, sql):
         with mysql.connector.connect(database=self.database) as conn:
@@ -31,7 +36,7 @@ class Connector(connector.SQLConnector):
         elif fmt == formats.NDJSON:
             dictionary = True
         else:
-            raise errors.UnsupportedFormat(fmt)
+            raise errors.UnsupportedFormatError(fmt)
 
         with mysql.connector.connect(database=self.database) as connection:
             with connection.cursor(dictionary=dictionary) as cursor:
