@@ -1,20 +1,25 @@
 import psycopg2
 import psycopg2.extras
-from tinybird_cdk import connector, export, formats, errors
 
+from tinybird_cdk import connector, errors, export, formats
+
+
+# WARNING: THIS CONNECTOR WAS JUST PROTOTYPED TO HELP DESIGN THE CDK, BUT IT IS
+# NOT USED AND IT DOES NOT HAVE TESTS.
+#
 # The environment variables supported by this connector are documented here:
 #
 #     https://www.postgresql.org/docs/14/libpq-envars.html
 #
 class Connector(connector.SQLConnector):
     def get_scopes(self):
-        raise 'Not implemented'
+        raise Exception('Not implemented')
 
     def list_scope(self, _parents={}):
-        raise 'Not implemented'
+        raise Exception('Not implemented')
 
-    def suggest_schema(self, parents):
-        raise 'Not implemented'
+    def suggest_schema(self, _scopes):
+        raise Exception('Not implemented')
 
     def _query(self, sql):
         with psycopg2.connect() as connection:
@@ -27,7 +32,7 @@ class Connector(connector.SQLConnector):
             return self._export_to_csv(query)
         if fmt == formats.NDJSON:
             return self._export_to_ndjson(query)
-        raise errors.UnsupportedFormat(fmt)
+        raise errors.UnsupportedFormatError(fmt)
 
     # https://www.postgresql.org/docs/14/sql-copy.html.
     def _export_to_csv(self, query):
