@@ -1,6 +1,10 @@
 from contextlib import closing
+
 import snowflake.connector
-from tinybird_cdk import config, logger, connector, export, formats, errors, utils, cloud
+
+from tinybird_cdk import (cloud, config, connector, errors, export, formats,
+                          logger, utils)
+
 
 # The `snowql` CLI for Snowflake understands a good deal of environment
 # variables:
@@ -20,11 +24,7 @@ class Connector(connector.SQLConnector):
     TIMESTAMP_FORMAT_NTZ = 'YYYY-MM-DD HH24:MI:SS.FF3'
 
     # https://docs.snowflake.com/en/sql-reference/sql/copy-into-location.html#type-csv
-    # https://docs.snowflake.com/en/sql-reference/sql/copy-into-location.html#type-json
-    FILE_FORMAT_FOR = {
-        formats.CSV: "TYPE=CSV COMPRESSION=NONE FIELD_DELIMITER=',' RECORD_DELIMITER='\\n' ESCAPE_UNENCLOSED_FIELD=NONE FIELD_OPTIONALLY_ENCLOSED_BY='\"' BINARY_FORMAT=HEX NULL_IF=()",
-        formats.NDJSON: 'TYPE=JSON COMPRESSION=NONE BINARY_FORMAT=HEX'
-    }
+    FILE_FORMAT_FOR_CSV = "TYPE=CSV COMPRESSION=NONE FIELD_DELIMITER=',' RECORD_DELIMITER='\\n' ESCAPE_UNENCLOSED_FIELD=NONE FIELD_OPTIONALLY_ENCLOSED_BY='\"' BINARY_FORMAT=HEX NULL_IF=()"
 
     def __init__(self):
         super().__init__()
@@ -39,10 +39,10 @@ class Connector(connector.SQLConnector):
         )
 
     def list_scope(self, parents={}):
-        raise 'Not implemented'
+        raise Exception('Not implemented')
 
-    def suggest_schema(self, parents):
-        raise 'Not implemented'
+    def suggest_schema(self, _scopes):
+        raise Exception('Not implemented')
 
     def _query(self, sql):
         with closing(self._connection()) as connection:
@@ -51,9 +51,8 @@ class Connector(connector.SQLConnector):
                 return cursor.fetchall()
 
     def _export(self, query, fmt):
-        file_format = self.FILE_FORMAT_FOR.get(fmt)
-        if not file_format:
-            raise errors.UnsupportedFormat(fmt)
+        if fmt != formats.CSV:
+            raise errors.UnsupportedFormatError(fmt)
 
         with closing(self._connection()) as connection:
             logger.info('Connected to Snowflake')
@@ -78,7 +77,7 @@ class Connector(connector.SQLConnector):
                 # https://docs.snowflake.com/en/sql-reference/sql/copy-into-location.html
                 sql = f'''
                     COPY INTO {external_stage} FROM ({query})
-                      FILE_FORMAT = ({file_format})
+                      FILE_FORMAT = ({self.FILE_FORMAT_FOR_CSV})
                       MAX_FILE_SIZE = {self.MAX_FILE_SIZE}'''
                 logger.debug(f'Executing SQL statement\n{sql}')
                 cursor.execute(sql)
